<div align=center>
  <h1>Model Predictive Path Integral control</h1>
</div>

## Description

The Model Predictive Path Integral (MPPI) control.


## Related papers
- 2018: [Information-Theoretic Model Predictive Control: Theory and Applications to Autonomous Driving](https://ieeexplore.ieee.org/stamp/stamp.jsp?arnumber=8558663)
- 2017: [Information Theoretic MPC for Model-Based Reinforcement Learning](https://ieeexplore.ieee.org/stamp/stamp.jsp?tp=&arnumber=7989202)
- 2016: [Aggressive driving with model predictive path integral control](https://ieeexplore.ieee.org/document/7487277)
